@@ -27,8 +27,8 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QMenuBar>
-#include <QtCore/QMetaClassInfo>
-#include <QtCore/QObject>
+#include <QMetaClassInfo>
+#include <QObject>
 #include <QList>
 #include <QPushButton>
 #include <QRadioButton>
@@ -73,12 +73,12 @@ bool KAcceleratorManagerPrivate::standardName(const QString &str)
 
 KAcceleratorManagerPrivate::Item::~Item()
 {
-    if (m_children)
+    if (m_children) {
         while (!m_children->isEmpty()) {
             delete m_children->takeFirst();
         }
-
-    delete m_children;
+        delete m_children;
+    }
 }
 
 void KAcceleratorManagerPrivate::Item::addChild(Item *item)
@@ -658,7 +658,7 @@ void KAccelManagerAlgorithm::findAccelerators(KAccelStringList &result, QString
     KAccelStringList accel_strings = result;
 
     // initially remove all accelerators
-    for (KAccelStringList::Iterator it = result.begin(); it != result.end(); ++it) {
+    for (KAccelStringList::Iterator it = result.begin(), total = result.end(); it != total; ++it) {
         (*it).setAccel(-1);
     }
 
@@ -791,8 +791,10 @@ void KPopupAccelManager::setMenuEntries(const KAccelStringList &list)
         // Check if iconText was generated by Qt. In that case ignore it (no support for CJK accelerators) and set it from the text.
         if (iconText == copy_of_qt_strippedText(oldText)) {
             iconText = removeAcceleratorMarker(oldText);
+            if (iconText != maction->iconText()) {
+                maction->setIconText(iconText);
+            }
         }
-        maction->setIconText(iconText);
 
         if (KAcceleratorManagerPrivate::checkChange(list[cnt])) {
             maction->setText(list[cnt].accelerated());
